@@ -1,23 +1,11 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2000 Matej Koss <koss@miesto.sk>
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2007 Rafael Fernández López <ereslibre@kde.org>
-    Copyright (C) 2009 Shaun Reich <shaun.reich@kdemail.net>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2000 Matej Koss <koss@miesto.sk>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2007 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2009 Shaun Reich <shaun.reich@kdemail.net>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kwidgetjobtracker.h"
@@ -33,12 +21,11 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QGridLayout>
-#include <QMenu>
 #include <QEvent>
 #include <QStyle>
 
-#include <ksqueezedtextlabel.h>
-#include <kseparator.h>
+#include <KSqueezedTextLabel>
+#include <KSeparator>
 
 void KWidgetJobTracker::Private::_k_showProgressWidget()
 {
@@ -297,7 +284,7 @@ void KWidgetJobTracker::Private::ProgressWidget::totalAmount(KJob::Unit unit, qu
             return;
         }
         totalSize = amount;
-        if (startTime.isNull()) {
+        if (!startTime.isValid()) {
             startTime.start();
         }
         break;
@@ -317,6 +304,14 @@ void KWidgetJobTracker::Private::ProgressWidget::totalAmount(KJob::Unit unit, qu
         totalDirs = amount;
         showTotals();
         break;
+
+    case KJob::Items:
+        if (totalItems == amount) {
+            return;
+        }
+        totalItems = amount;
+        showTotals();
+        break;
     }
 }
 
@@ -335,8 +330,7 @@ void KWidgetJobTracker::Private::ProgressWidget::processedAmount(KJob::Unit unit
             //~ singular %1 of %2 complete
             //~ plural %1 of %2 complete
             tmp = QCoreApplication::translate("KWidgetJobTracker", "%1 of %2 complete", "", amount)
-                  .arg(KJobTrackerFormatters::byteSize(amount))
-                  .arg(KJobTrackerFormatters::byteSize(totalSize));
+                  .arg(KJobTrackerFormatters::byteSize(amount), KJobTrackerFormatters::byteSize(totalSize));
         } else {
             tmp = KJobTrackerFormatters::byteSize(amount);
         }
@@ -378,12 +372,22 @@ void KWidgetJobTracker::Private::ProgressWidget::processedAmount(KJob::Unit unit
         //~ plural %1 / %n files
         tmp += QCoreApplication::translate("KWidgetJobTracker", "%1 / %n file(s)", "", totalFiles).arg(processedFiles);
         progressLabel->setText(tmp);
+        break;
+
+    case KJob::Items:
+        if (processedItems == amount) {
+            return;
+        }
+        processedItems = amount;
+        tmp = QCoreApplication::translate("KWidgetJobTracker", "%1 / %n item(s)", "", totalItems).arg(processedItems);
+        progressLabel->setText(tmp);
+        break;
     }
 }
 
 void KWidgetJobTracker::Private::ProgressWidget::percent(unsigned long percent)
 {
-    QString title = caption + " (";
+    QString title = caption + QLatin1String(" (");
 
     if (totalSizeKnown) {
         title += QCoreApplication::translate("KWidgetJobTracker", "%1% of %2").arg(percent).arg(
@@ -396,7 +400,7 @@ void KWidgetJobTracker::Private::ProgressWidget::percent(unsigned long percent)
         title += QCoreApplication::translate("KWidgetJobTracker", "%1%").arg(percent);
     }
 
-    title += ')';
+    title += QLatin1Char(')');
 
     progressBar->setMaximum(100);
     progressBar->setValue(percent);
@@ -413,8 +417,7 @@ void KWidgetJobTracker::Private::ProgressWidget::speed(unsigned long value)
             const int remaining = 1000 * (totalSize - processedSize) / value;
             //~ singular %1/s (%2 remaining)
             //~ plural %1/s (%2 remaining)
-            speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s (%2 remaining)", "", remaining).arg(speedStr).arg(
-                                    KJobTrackerFormatters::duration(remaining)));
+            speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s (%2 remaining)", "", remaining).arg(speedStr, KJobTrackerFormatters::duration(remaining)));
         } else { // total size is not known (#24228)
             speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s", "speed in bytes per second").arg(speedStr));
         }
@@ -434,7 +437,7 @@ void KWidgetJobTracker::Private::ProgressWidget::slotClean()
     processedAmount(KJob::Bytes, totalSize);
     keepOpenCheck->setEnabled(false);
     pauseButton->setEnabled(false);
-    if (!startTime.isNull()) {
+    if (startTime.isValid()) {
         int s = startTime.elapsed();
         if (!s) {
             s = 1;
@@ -473,8 +476,8 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
 
     QGridLayout *grid = new QGridLayout();
     topLayout->addLayout(grid);
-    const int spacingHint = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-    grid->addItem(new QSpacerItem(spacingHint, 0), 0, 1);
+    const int horizontalSpacing = style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing);
+    grid->addItem(new QSpacerItem(horizontalSpacing, 0), 0, 1);
     // filenames or action name
     sourceInvite = new QLabel(QCoreApplication::translate("KWidgetJobTracker", "Source:", "The source url of a job"), this);
     grid->addWidget(sourceInvite, 0, 0);
@@ -510,7 +513,8 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     arrowButton->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
     arrowButton->setToolTip(QCoreApplication::translate("KWidgetJobTracker", "Click this to expand the dialog, to show details"));
     arrowState = Qt::DownArrow;
-    connect(arrowButton, SIGNAL(clicked()), this, SLOT(_k_arrowToggled()));
+    connect(arrowButton, &QPushButton::clicked,
+            this, &KWidgetJobTracker::Private::ProgressWidget::arrowClicked);
     hBox->addWidget(arrowButton);
     hBox->addStretch(1);
 
@@ -525,7 +529,8 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
 
     pauseButton = new QPushButton(QCoreApplication::translate("KWidgetJobTracker", "&Pause"), this);
     pauseButton->setVisible(job && (job->capabilities() & KJob::Suspendable));
-    connect(pauseButton, SIGNAL(clicked()), this, SLOT(_k_pauseResumeClicked()));
+    connect(pauseButton, &QPushButton::clicked,
+            this, &KWidgetJobTracker::Private::ProgressWidget::pauseResumeClicked);
     hBox->addWidget(pauseButton);
 
     hBox = new QHBoxLayout();
@@ -544,7 +549,8 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     progressLabel->hide();
 
     keepOpenCheck = new QCheckBox(QCoreApplication::translate("KWidgetJobTracker", "&Keep this window open after transfer is complete"), this);
-    connect(keepOpenCheck, SIGNAL(toggled(bool)), this, SLOT(_k_keepOpenToggled(bool)));
+    connect(keepOpenCheck, &QCheckBox::toggled,
+            this, &KWidgetJobTracker::Private::ProgressWidget::keepOpenToggled);
     topLayout->addWidget(keepOpenCheck);
     keepOpenCheck->hide();
 
@@ -552,13 +558,15 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     topLayout->addLayout(hBox);
 
     openFile = new QPushButton(QCoreApplication::translate("KWidgetJobTracker", "Open &File"), this);
-    connect(openFile, SIGNAL(clicked()), this, SLOT(_k_openFile()));
+    connect(openFile, &QPushButton::clicked,
+            this, &KWidgetJobTracker::Private::ProgressWidget::openFileClicked);
     hBox->addWidget(openFile);
     openFile->setEnabled(false);
     openFile->hide();
 
     openLocation = new QPushButton(QCoreApplication::translate("KWidgetJobTracker", "Open &Destination"), this);
-    connect(openLocation, SIGNAL(clicked()), this, SLOT(_k_openLocation()));
+    connect(openLocation, &QPushButton::clicked,
+            this, &KWidgetJobTracker::Private::ProgressWidget::openLocationClicked);
     hBox->addWidget(openLocation);
     openLocation->hide();
 
@@ -567,7 +575,8 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     cancelClose = new QPushButton(this);
     cancelClose->setText(QCoreApplication::translate("KWidgetJobTracker", "&Cancel"));
     cancelClose->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
-    connect(cancelClose, SIGNAL(clicked()), this, SLOT(_k_stop()));
+    connect(cancelClose, &QPushButton::clicked,
+            this, &KWidgetJobTracker::Private::ProgressWidget::cancelClicked);
     hBox->addWidget(cancelClose);
 
     resize(sizeHint());
@@ -581,19 +590,18 @@ void KWidgetJobTracker::Private::ProgressWidget::showTotals()
     // Show the totals in the progress label, if we still haven't
     // processed anything. This is useful when the stat'ing phase
     // of CopyJob takes a long time (e.g. over networks).
-    if (processedFiles == 0 && processedDirs == 0) {
-        QString tmps;
-        if (totalDirs > 1)
-            // that we have a singular to translate looks weired but is only logical
-        {
-            //~ singular %n folder
-            //~ plural %n folders
-            tmps = QCoreApplication::translate("KWidgetJobTracker", "%n folder(s)", "", totalDirs) + "   ";
+    if (processedFiles == 0 && processedDirs == 0 && processedItems == 0) {
+        QString total;
+        if (totalItems > 1) {
+            total = QCoreApplication::translate("KWidgetJobTracker", "%n item(s)", "", totalItems);
+            progressLabel->setText(total);
+        } else {
+            if (totalDirs > 1) {
+                total = QCoreApplication::translate("KWidgetJobTracker", "%n folder(s)", "", totalDirs) + QLatin1String("   ");
+            }
+            total += QCoreApplication::translate("KWidgetJobTracker", "%n file(s)", "", totalFiles);
+            progressLabel->setText(total);
         }
-        //~ singular %n file
-        //~ plural %n files
-        tmps += QCoreApplication::translate("KWidgetJobTracker", "%n file(s)", "", totalFiles);
-        progressLabel->setText(tmps);
     }
 }
 
@@ -633,7 +641,7 @@ void KWidgetJobTracker::Private::ProgressWidget::checkDestination(const QUrl &de
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::_k_keepOpenToggled(bool keepOpen)
+void KWidgetJobTracker::Private::ProgressWidget::keepOpenToggled(bool keepOpen)
 {
     if (keepOpen) {
         Q_ASSERT(!tracker->d->eventLoopLocker);
@@ -644,17 +652,17 @@ void KWidgetJobTracker::Private::ProgressWidget::_k_keepOpenToggled(bool keepOpe
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::_k_openFile()
+void KWidgetJobTracker::Private::ProgressWidget::openFileClicked()
 {
     QProcess::startDetached(QStringLiteral("kde-open"), QStringList() << location.toDisplayString());
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::_k_openLocation()
+void KWidgetJobTracker::Private::ProgressWidget::openLocationClicked()
 {
     QProcess::startDetached(QStringLiteral("kde-open"), QStringList() << location.adjusted(QUrl::RemoveFilename).toString());
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::_k_pauseResumeClicked()
+void KWidgetJobTracker::Private::ProgressWidget::pauseResumeClicked()
 {
     if (jobRegistered && !suspendedProperty) {
         tracker->slotSuspend(job);
@@ -663,7 +671,7 @@ void KWidgetJobTracker::Private::ProgressWidget::_k_pauseResumeClicked()
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::_k_stop()
+void KWidgetJobTracker::Private::ProgressWidget::cancelClicked()
 {
     if (jobRegistered) {
         tracker->slotStop(job);
@@ -671,7 +679,7 @@ void KWidgetJobTracker::Private::ProgressWidget::_k_stop()
     closeNow();
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::_k_arrowToggled()
+void KWidgetJobTracker::Private::ProgressWidget::arrowClicked()
 {
     if (arrowState == Qt::DownArrow) {
         //The arrow is in the down position, dialog is collapsed, expand it and change icon.
